#ifndef NT2_INCLUDE_FUNCTIONS_CAUCHY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAUCHY_HPP_INCLUDED

#include <nt2/gallery/include/functions/cauchy.hpp>

#endif
